@@ -3,11 +3,13 @@
 {
     'name': 'Project',
     'name_bg_BG': 'Проект',
+    'name_ca_ES': 'Projectes',
     'name_de_DE': 'Projekte',
+    'name_es_AR': 'Proyecto',
     'name_es_CO': 'Proyectos',
-    'name_es_ES': 'Proyecto',
+    'name_es_ES': 'Proyectos',
     'name_fr_FR': 'Projet',
-    'version': '2.2.0',
+    'version': '2.4.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -17,15 +19,17 @@
     'description_bg_BG': '''Модул за проекти с:
     - Управление на проекти
 ''',
+    'description_ca_ES': '''Mòdul per la gestió de projectes.''',
     'description_de_DE': '''Projektmodul für:
     - Projektverwaltung
+''',
+    'description_es_AR': '''Módulo de proyecto con:
+    - Gestión de proyecto
 ''',
     'description_es_CO': '''Módulo de proyectos con:
     - Gestión de proyectos
 ''',
-    'description_es_ES': '''Módulo de proyecto con:
-    - Gestión de proyecto
-''',
+    'description_es_ES': '''Módulo para la gestión de proyectos.''',
     'description_fr_FR': '''Module projet avec:
     - Gestion de projet
 ''',
@@ -41,8 +45,10 @@
     ],
     'translation': [
         'locale/bg_BG.po',
+        'locale/ca_ES.po',
         'locale/cs_CZ.po',
         'locale/de_DE.po',
+        'locale/es_AR.po',
         'locale/es_CO.po',
         'locale/es_ES.po',
         'locale/fr_FR.po',
